@@ -16,7 +16,7 @@ BUNDLED_DATA_DIRECTORY = os.path.join(str(Path(os.path.dirname(__file__))), "dat
 
 LOCAL_HTML_DIRECTORY_PATH = os.path.join(CONFIG_DIRECTORY, "data", "docs")
 
-BASE_DOCUMENTATION_URL = "https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_actions-resources-contextkeys.partial.html"
+BASE_DOCUMENTATION_URL = "https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_actions-resources-contextkeys.html"
 
 # Data json file
 BUNDLED_DATASTORE_FILE_PATH = os.path.join(
